==> Mopidy-Mopify-1.5.12.tar.gz: Mopidy-Mopify-1.5.12/mopidy_mopify/static/debug/src/app/services/discover.service.js <==
angular.module('mopify.services.discover', [
  'mopify.services.history',
  'mopify.services.tasteprofile',
  'angular-echonest'
]).factory('Discover', [
  '$q',
  'History',
  'TasteProfile',
  'Echonest',
  function ($q, History, TasteProfile, Echonest) {
    'use strict';
    function Discover() {
      this.data = { blocks: [] };
    }
    Discover.prototype.getBrowseBlocks = function () {
      var that = this;
      var deferred = $q.defer();
      if (that.data.blocks.length === 0) {
        that.generateBrowseContent().then(function (blocks) {
          deferred.resolve(blocks);
          that.data.blocks = blocks;
        });
      } else {
        deferred.resolve(that.data.blocks);
      }
      return deferred.promise;
    };
    /**
     * Generate new browse content
     * @return {$q.defer().promise}
     */
    Discover.prototype.generateBrowseContent = function () {
      var that = this;
      var deferred = $q.defer();
      var history = History.getTracks().reverse().splice(0, 50);
      var echonest = [];
      var builtblocks = [];
      // Get a catalog radio based on the tasteprofile id 
      var parameters = {
          results: 50,
          type: 'catalog-radio',
          seed_catalog: TasteProfile.id,
          bucket: [
            'id:spotify',
            'tracks'
          ],
          limit: true
        };
      Echonest.playlist.static(parameters).then(function (songs) {
        echonest = songs;
        _.forEach(echonest, function (item) {
          builtblocks.push({
            type: 'echonest',
            echonest: item
          });
        });
        _.forEach(history, function (item) {
          builtblocks.push({
            type: 'artist',
            artist: item.track.artists[0]
          });
        });
        // Shuffle the array
        deferred.resolve(_.shuffle(builtblocks));
      });
      return deferred.promise;
    };
    return new Discover();
  }
]);

==> Mopidy-Mopify-1.6.0.tar.gz: Mopidy-Mopify-1.6.0/mopidy_mopify/static/debug/src/app/services/discover.service.js <==
'use strict';
angular.module('mopify.services.discover', ['mopify.services.history']).factory('Discover', [
  '$q',
  'History',
  'Spotify',
  function ($q, History, Spotify) {
    function Discover() {
      this.data = { blocks: [] };
    }
    Discover.prototype.getBrowseBlocks = function () {
      var that = this;
      var deferred = $q.defer();
      if (that.data.blocks.length === 0) {
        that.generateBrowseContent().then(function (blocks) {
          deferred.resolve(blocks);
          that.data.blocks = blocks;
        });
      } else {
        deferred.resolve(that.data.blocks);
      }
      return deferred.promise;
    };
    /**
     * Generate new browse content
     * @return {$q.defer().promise}
     */
    Discover.prototype.generateBrowseContent = function () {
      var history = History.getTracks().reverse().splice(0, 50);
      return Spotify.getUserTopTracks({ limit: 5 }).then(function (response) {
        return _.map(response.items, function (t) {
          return t.id;
        });
      }).then(function (ids) {
        return Spotify.getRecommendations({
          limit: 100,
          seed_tracks: ids
        });
      }).then(function (response) {
        var songs = response.tracks;
        var builtblocks = [];
        _.forEach(songs, function (item) {
          builtblocks.push({
            type: 'spotify',
            spotify: item
          });
        });
        _.forEach(history, function (item) {
          builtblocks.push({
            type: 'artist',
            artist: item.track.artists[0]
          });
        });
        // Shuffle the array
        return _.shuffle(builtblocks);
      });
    };
    return new Discover();
  }
]);
